==> haskell-findbin-0.0.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-findbin.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: FindBin
version: 0.0.5
id: FindBin-0.0.5-7YUNl8W6bN9GM4CQnaO2CD
key: FindBin-0.0.5-7YUNl8W6bN9GM4CQnaO2CD
license: BSD3
copyright: 2008-2011 Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
stability: Stable
homepage: https://github.com/audreyt/findbin
synopsis: Locate directory of original program
description:
    This module locates the full directory to the running program,
    to allow the use of paths relative to it.
    FindBin supports invocation of Haskell programs via "ghci",
    via "runhaskell/runghc", as well as compiled as an executable.
category: System
author: Audrey Tang <audreyt@audreyt.org>
exposed: True
indefinite: False
exposed-modules:
    System.Environment.FindBin
abi: 9b9012f280b1c9cac3fd4bdf399521f7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/FindBin-0.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/FindBin-0.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/FindBin-0.0.5
hs-libraries: HSFindBin-0.0.5-7YUNl8W6bN9GM4CQnaO2CD
depends:
    base-4.10.1.0 directory-1.3.0.2 filepath-1.4.1.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
haddock-interfaces: /usr/share/doc/haskell-findbin/html/FindBin.haddock
haddock-html: /usr/share/doc/haskell-findbin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-findbin-0.0.5-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-findbin.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: FindBin
version: 0.0.5
id: FindBin-0.0.5-9Wq4xeegf9B5MTFVBLHETs
key: FindBin-0.0.5-9Wq4xeegf9B5MTFVBLHETs
license: BSD-3-Clause
copyright: 2008-2011 Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang <audreyt@audreyt.org>
stability: Stable
homepage: https://github.com/audreyt/findbin
synopsis: Locate directory of original program
description:
    This module locates the full directory to the running program,
    to allow the use of paths relative to it.
    FindBin supports invocation of Haskell programs via "ghci",
    via "runhaskell/runghc", as well as compiled as an executable.
category: System
abi: 7318eb48f956dffb1b356862fdf5472b
exposed: True
exposed-modules:
    System.Environment.FindBin
import-dirs: /usr/lib/ghc-8.4.3/site-local/FindBin-0.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/FindBin-0.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/FindBin-0.0.5
hs-libraries: HSFindBin-0.0.5-9Wq4xeegf9B5MTFVBLHETs
depends:
    base-4.11.1.0 directory-1.3.1.5 filepath-1.4.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
haddock-interfaces: /usr/share/doc/haskell-findbin/html/FindBin.haddock
haddock-html: /usr/share/doc/haskell-findbin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
